        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 25 <br>2,3,5,7,11,17,19,20,22,23,25,26,27,29,31,32,33,34,37,38,40,43,44,48,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <strong>control</strong><br>0,1,4,6,8,9,10,12,21,24,30,39,42';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 13 <br>13,14,15,16,18,28,35,36,41,45,46,47,49';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 25 <br>2,3,5,7,11,17,19,20,22,23,25,26,27,29,31,32,33,34,37,38,40,43,44,48,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <strong>control</strong><br>0,1,4,6,8,9,10,12,21,24,30,39,42';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 13 <br>13,14,15,16,18,28,35,36,41,45,46,47,49';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 25 <br>2,3,5,7,11,17,19,20,22,23,25,26,27,29,31,32,33,34,37,38,40,43,44,48,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <strong>control</strong><br>0,1,4,6,8,9,10,12,21,24,30,39,42';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 13 <br>13,14,15,16,18,28,35,36,41,45,46,47,49';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 25 <br>2,3,5,7,11,17,19,20,22,23,25,26,27,29,31,32,33,34,37,38,40,43,44,48,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <strong>control</strong><br>0,1,4,6,8,9,10,12,21,24,30,39,42';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 13 <br>13,14,15,16,18,28,35,36,41,45,46,47,49';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 25 <br>2,3,5,7,11,17,19,20,22,23,25,26,27,29,31,32,33,34,37,38,40,43,44,48,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <strong>control</strong><br>0,1,4,6,8,9,10,12,21,24,30,39,42';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 13 <br>13,14,15,16,18,28,35,36,41,45,46,47,49';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 25 <br>2,3,5,7,11,17,19,20,22,23,25,26,27,29,31,32,33,34,37,38,40,43,44,48,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>10</strong> miembros: 13 <strong>control</strong><br>0,1,4,6,8,9,10,12,21,24,30,39,42';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260502 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>3</strong> representante: <strong>36</strong> miembros: 13 <br>13,14,15,16,18,28,35,36,41,45,46,47,49';}
}
